@@ -39,7 +39,7 @@ class Transition;
 namespace Mlt
 {
 class Producer;
-};
+}
 
 class ClipItem : public AbstractClipItem
 {
@@ -75,7 +75,7 @@ public:
 
     /** @brief Adds an effect to the clip.
     * @return The parameters that will be passed to Mlt */
-    EffectsParameterList addEffect(const QDomElement effect, bool animate = true);
+    EffectsParameterList addEffect(QDomElement effect, bool animate = true);
 
     /** @brief Deletes the effect with id @param index. */
     void deleteEffect(QString index);
@@ -85,21 +85,29 @@ public:
 
     /** @brief Gets a unique (?) effect id. */
     int effectsCounter();
+    
+        /** @brief Gets a copy of the xml of an effect.
+    * @param ix The effect's list index (starting from 0)
+    * @return A copy of the effect's xml */
+    QDomElement effect(int ix) const;
 
     /** @brief Gets a copy of the xml of an effect.
-    * @param ix The effect's index in effectlist
+    * @param ix The effect's index in effectlist (starting from 1)
     * @return A copy of the effect's xml */
-    QDomElement effectAt(int ix) const;
+    QDomElement effectAtIndex(int ix) const;
 
     /** @brief Gets the xml of an effect.
-    * @param ix The effect's index in effectlist
+    * @param ix The effect's index in effectlist (starting from 1)
     * @return The effect's xml */
-    QDomElement getEffectAt(int ix) const;
+    QDomElement getEffectAtIndex(int ix) const;
 
     /** @brief Replaces an effect.
     * @param ix The effect's index in effectlist
     * @param effect The new effect */
-    void setEffectAt(int ix, QDomElement effect);
+    void updateEffect(QDomElement effect);
+    /** @brief Enable / disable a list of effect from their indexes. */
+    void enableEffects(QList <int> indexes, bool disable);
+    bool moveEffect(QDomElement effect, int ix);
     void flashClip();
     void addTransition(Transition*);
 
@@ -175,6 +183,9 @@ public:
     void resetFrameWidth(int width);
     /** @brief Clip is about to be deleted, block thumbs. */
     void stopThumbs();
+    
+    /** @brief Get a free index value for effect group. */
+    int nextFreeEffectGroupIndex() const;
 
 protected:
     //virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
