@@ -24,11 +24,22 @@
 #include "gentime.h"
 #include "effectslist.h"
 
-#include <QTreeWidgetItem>
 #include <KLocale>
+#include <QDebug>
+
+#include <QTreeWidgetItem>
+ #include <QtCore/QString>
 
 const int MAXCLIPDURATION = 15000;
 
+namespace Kdenlive {
+  enum MONITORID { noMonitor, clipMonitor, projectMonitor, recordMonitor, stopmotionMonitor, dvdMonitor };
+  /*const QString clipMonitor("clipMonitor");
+  const QString recordMonitor("recordMonitor");
+  const QString projectMonitor("projectMonitor");
+  const QString stopmotionMonitor("stopmotionMonitor");*/
+}
+
 enum OPERATIONTYPE { NONE = 0, MOVE = 1, RESIZESTART = 2, RESIZEEND = 3, FADEIN = 4, FADEOUT = 5, TRANSITIONSTART = 6, TRANSITIONEND = 7, MOVEGUIDE = 8, KEYFRAME = 9, SEEK = 10, SPACER = 11, RUBBERSELECTION = 12};
 enum CLIPTYPE { UNKNOWN = 0, AUDIO = 1, VIDEO = 2, AV = 3, COLOR = 4, IMAGE = 5, TEXT = 6, SLIDESHOW = 7, VIRTUAL = 8, PLAYLIST = 9 };
 
@@ -57,7 +68,7 @@ enum MessageType {
 
 enum TRACKTYPE { AUDIOTRACK = 0, VIDEOTRACK = 1 };
 
-enum PROXYSTATUS { NOPROXY = 0, PROXYWAITING = -1, CREATINGPROXY = -2, PROXYDONE = -3, PROXYCRASHED = -4};
+enum CLIPJOBSTATUS { NOJOB = 0, JOBWAITING = -1, JOBWORKING = -2, JOBDONE = -3, JOBCRASHED = -4, JOBABORTED = -5};
 
 struct TrackInfo {
     TRACKTYPE type;
@@ -84,6 +95,19 @@ struct ItemInfo {
     int track;
 };
 
+struct TransitionInfo {
+/** startPos is the position where the clip starts on the track */
+    GenTime startPos;
+    /** endPos is the duration where the clip ends on the track */
+    GenTime endPos;
+    /** the track on which the transition is (b_track)*/
+    int b_track;
+    /** the track on which the transition is applied (a_track)*/
+    int a_track;
+    /** Does the user request for a special a_track */
+    bool forceTrack;
+};
+
 struct MltVideoProfile {
     QString path;
     QString description;
@@ -97,8 +121,56 @@ struct MltVideoProfile {
     int display_aspect_num;
     int display_aspect_den;
     int colorspace;
+    bool operator==(const MltVideoProfile& point) const
+    {
+        if (!description.isEmpty() && point.description  == description) return true;
+        return      point.frame_rate_num == frame_rate_num &&
+                    point.frame_rate_den  == frame_rate_den  &&
+                    point.width == width &&
+                    point.height == height &&
+                    point.progressive == progressive &&
+                    point.sample_aspect_num == sample_aspect_num &&
+                    point.sample_aspect_den == sample_aspect_den &&
+                    point.display_aspect_den == display_aspect_den &&
+                    point.colorspace == colorspace;
+    }
+    bool operator!=(const MltVideoProfile &other) const {
+        return !(*this == other);
+    }
 };
 
+/**)
+ * @class EffectInfo
+ * @brief A class holding some meta info for effects widgets, like state (collapsed or not, ...)
+ * @author Jean-Baptiste Mardelle
+ */
+
+class EffectInfo
+{
+public:
+    EffectInfo() {isCollapsed = false; groupIndex = -1; groupIsCollapsed = false;}
+    bool isCollapsed;
+    bool groupIsCollapsed;
+    int groupIndex;
+    QString groupName;
+    QString toString() const {
+        QStringList data;
+	// effect collapsed state: 0 = effect not collapsed, 1 = effect collapsed, 
+	// 2 = group collapsed - effect not, 3 = group and effect collapsed
+	int collapsedState = (int) isCollapsed;
+	if (groupIsCollapsed) collapsedState += 2;
+	data << QString::number(collapsedState) << QString::number(groupIndex) << groupName;
+	return data.join("/");
+    }
+    void fromString(QString value) {
+	if (value.isEmpty()) return;
+	QStringList data = value.split("/");
+	isCollapsed = data.at(0).toInt() == 1 || data.at(0).toInt() == 3;
+	groupIsCollapsed = data.at(0).toInt() == 3;
+	if (data.count() > 1) groupIndex = data.at(1).toInt();
+	if (data.count() > 2) groupName = data.at(2);
+    }
+};
 
 class EffectParameter
 {
@@ -199,5 +271,7 @@ private:
 
 };
 
+QDebug operator << (QDebug qd, const ItemInfo &info);
+
 
 #endif
