@@ -18,7 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include "kdenlive-config.h"
+#include "config-kdenlive.h"
 #include "mainwindow.h"
 
 #include <KApplication>
