@@ -39,6 +39,10 @@ public:
     void resetProfiles(Timecode tc);
     void stopActiveMonitor();
     AbstractRender *activeRenderer();
+    /** Searches for a monitor with the given name.
+	@return NULL, if no monitor could be found, or the monitor otherwise.
+    */
+    AbstractMonitor *monitor(Kdenlive::MONITORID monitorName);
     void updateScopeSource();
     void clearScopeSource();
 
@@ -46,8 +50,8 @@ public slots:
 
     /** @brief Activates a monitor.
      * @param name name of the monitor to activate */
-    bool activateMonitor(const QString &name = QString());
-    bool isActive(const QString &name) const;
+    bool activateMonitor(Kdenlive::MONITORID);
+    bool isActive(Kdenlive::MONITORID id) const;
     void slotPlay();
     void slotPause();
     void slotPlayZone();
@@ -61,6 +65,9 @@ public slots:
     void slotStart();
     void slotEnd();
     void slotResetProfiles();
+    
+    /** @brief Switch current monitor to fullscreen. */
+    void slotSwitchFullscreen();
 
     /** @brief Switches between project and clip monitor.
      * @ref activateMonitor
