@@ -47,74 +47,73 @@ public:
                const QModelIndex &index) const {
         if (index.column() == 1) {
             painter->save();
-            int factor = 2;
             QStyleOptionViewItemV4 opt(option);
             QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
             const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
             style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 
-            if (option.state & QStyle::State_Selected) {
-                painter->setPen(option.palette.highlightedText().color());
-                factor = 3;
-            }// else painter->setPen(option.palette.color(QPalette::Text));
             QFont font = painter->font();
             font.setBold(true);
             painter->setFont(font);
             QRect r1 = option.rect;
             r1.adjust(0, textMargin, 0, - textMargin);
-            int mid = (int)((r1.height() / factor));
+            int mid = (int)((r1.height() / 2));
             r1.setBottom(r1.y() + mid);
-            painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data().toString());
-            r1.setBottom(r1.bottom() + mid);
-            r1.setTop(r1.bottom() - mid);
+            QRect bounding;
+            painter->drawText(r1, Qt::AlignLeft | Qt::AlignTop ,index.data().toString(), &bounding);
+            r1.moveTop(r1.bottom() - textMargin);
             font.setBold(false);
             painter->setFont(font);
-            painter->drawText(r1, Qt::AlignLeft | Qt::AlignVCenter , index.data(Qt::UserRole).toString());
-            if (factor > 2) {
-                r1.setBottom(r1.bottom() + mid);
+            painter->drawText(r1, Qt::AlignLeft | Qt::AlignTop , index.data(Qt::UserRole).toString());
+            int progress = index.data(Qt::UserRole + 3).toInt();
+            if (progress > 0 && progress < 100) {
+                // draw progress bar
+                QColor color = option.palette.alternateBase().color();
+                QColor fgColor = option.palette.text().color();
+                color.setAlpha(150);
+                fgColor.setAlpha(150);
+                painter->setBrush(QBrush(color));
+                painter->setPen(QPen(fgColor));
+                int width = qMin(200, r1.width() - 4);
+                QRect bgrect(r1.left() + 2, option.rect.bottom() - 6 - textMargin, width, 6);
+                painter->drawRoundedRect(bgrect, 3, 3);
+                painter->setBrush(QBrush(fgColor));
+                bgrect.adjust(2, 2, 0, -1);
+                painter->setPen(Qt::NoPen);
+                bgrect.setWidth((width - 2) * progress / 100);
+                painter->drawRect(bgrect);
+            } else {
+                r1.setBottom(opt.rect.bottom());
                 r1.setTop(r1.bottom() - mid);
-                painter->drawText(r1, Qt::AlignLeft | Qt::AlignVCenter , index.data(Qt::UserRole + 5).toString());
+                painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data(Qt::UserRole + 5).toString());
             }
             painter->restore();
-        } else if (index.column() == 2) {
-            // Set up a QStyleOptionProgressBar to precisely mimic the
-            // environment of a progress bar.
-            QStyleOptionViewItemV4 opt(option);
-            QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
-            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
-
-            QStyleOptionProgressBar progressBarOption;
-            progressBarOption.state = option.state;
-            progressBarOption.direction = QApplication::layoutDirection();
-            QRect rect = option.rect;
-            int mid = rect.height() / 2;
-            rect.setTop(rect.top() + mid / 2);
-            rect.setHeight(mid);
-            progressBarOption.rect = rect;
-            progressBarOption.fontMetrics = QApplication::fontMetrics();
-            progressBarOption.minimum = 0;
-            progressBarOption.maximum = 100;
-            progressBarOption.textAlignment = Qt::AlignCenter;
-            progressBarOption.textVisible = true;
-
-            // Set the progress and text values of the style option.
-            int progress = index.data(Qt::UserRole).toInt();
-            progressBarOption.progress = progress < 0 ? 0 : progress;
-            progressBarOption.text = QString().sprintf("%d%%", progressBarOption.progress);
-
-            // Draw the progress bar onto the view.
-            QApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
         } else QStyledItemDelegate::paint(painter, option, index);
     }
 };
 
 
+class RenderJobItem: public QTreeWidgetItem
+{
+public:
+    explicit RenderJobItem(QTreeWidget * parent, const QStringList & strings, int type = QTreeWidgetItem::Type);
+    void setStatus(int status);
+    int status() const;
+    void setMetadata(const QString &data);
+    const QString metadata() const;
+    void render();
+
+private:
+    int m_status;
+    QString m_data;    
+};
+
 class RenderWidget : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit RenderWidget(const QString &projectfolder, bool enableProxy, QWidget * parent = 0);
+    explicit RenderWidget(const QString &projectfolder, bool enableProxy, MltVideoProfile profile, QWidget * parent = 0);
     virtual ~RenderWidget();
     void setGuides(QDomElement guidesxml, double duration);
     void focusFirstVisibleItem();
@@ -141,7 +140,7 @@ protected:
     virtual QSize sizeHint() const;
 
 public slots:
-    void slotExport(bool scriptExport, int zoneIn, int zoneOut, const QString &playlistPath, const QString &scriptPath, bool exportAudio);
+    void slotExport(bool scriptExport, int zoneIn, int zoneOut, const QMap <QString, QString> metadata, const QString &playlistPath, const QString &scriptPath, bool exportAudio);
 
 private slots:
     void slotUpdateButtons(KUrl url);
@@ -183,8 +182,8 @@ private slots:
 
 private:
     Ui::RenderWidget_UI m_view;
-    MltVideoProfile m_profile;
     QString m_projectFolder;
+    MltVideoProfile m_profile;
     RenderViewDelegate *m_scriptsDelegate;
     RenderViewDelegate *m_jobsDelegate;
     bool m_blockProcessing;
@@ -198,8 +197,9 @@ private:
     void parseFile(QString exportFile, bool editable);
     void updateButtons();
     KUrl filenameWithExtension(KUrl url, QString extension);
+    /** @brief Check if a job needs to be started. */
     void checkRenderStatus();
-    void startRendering(QTreeWidgetItem *item);
+    void startRendering(RenderJobItem *item);
     void saveProfile(QDomElement newprofile);
     QList <QListWidgetItem *> m_renderItems;
     QList <QListWidgetItem *> m_renderCategory;
